@@ -11,7 +11,7 @@ use JSON::XS qw(decode_json encode_json);
 use Time::HiRes qw(gettimeofday time);
 use Data::Dumper;
 
-our $VERSION = "0.031";
+our $VERSION = "0.032";
 
 my %INFO_ROUTES = (
     version => '/version',
@@ -308,7 +308,9 @@ sub put {
     $self->{last_error} = undef;
 
     # at least one valid record
-    unless ($command->{table} && $command->{changes}->[0]->{row_key} && $command->{changes}->[0]->{row_cells}) {
+    unless ($command->{table} &&
+            (defined $command->{changes}->[0]->{row_key}) &&
+            $command->{changes}->[0]->{row_cells}) {
         die q/Must provide required parameters:
             IN: HASH => {
                table   => $table,
@@ -869,7 +871,7 @@ Information on error is stored in hbase object under key last error:
 
 =head1 VERSION
 
-Current version: 0.031
+Current version: 0.032
 
 =head1 AUTHOR
 
